clear all
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                            Michael Pokojovy                             % 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
figure(1);

set(gcf, 'PaperUnits', 'centimeters');
xSize = 24; ySize = 10;
xLeft = (21 - xSize)/2; yTop = (30 - ySize)/2;
set(gcf,'PaperPosition', [xLeft yTop xSize ySize]);
set(gcf,'Position',[0 0 xSize*50 ySize*50]);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
M = 51;
N = 51;

M2 = ceil(M/2);
N2 = ceil(N/2);

phi = linspace(1E-3, pi - 1E-3, M);
r   = linspace(1E-3, 0.5, N);

[R, PHI] = meshgrid(r, phi);

X = R.*cos(PHI);
Y = R.*sin(PHI);

Z = zeros(M, N);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
subplot(1, 2, 1);
hold on;

t = title('Krummliniges Gitter im Definitionsbereich', 'interpreter', 'latex');
set(t, 'FontSize', 16);

surf(X, Y, Z);
colormap pink;

plot(X(1,   :), Y(1,   :), 'r', 'LineWidth', 2);
plot(X(end, :), Y(end, :), 'r', 'LineWidth', 2);
plot(X(:,   1), Y(:,   1), 'r', 'LineWidth', 2);
plot(X(:, end), Y(:, end), 'r', 'LineWidth', 2);
plot(X(M2, :),  Y(M2,  :), 'b', 'LineWidth', 2);
plot(X(:,  N2), Y(:,  N2), 'm', 'LineWidth', 2);

Y = -Y;

surf(X, Y, Z);
colormap pink;
plot(X(1,   :), Y(1,   :), 'r', 'LineWidth', 2);
plot(X(end, :), Y(end, :), 'r', 'LineWidth', 2);
plot(X(:,   1), Y(:,   1), 'r', 'LineWidth', 2);
plot(X(:, end), Y(:, end), 'r', 'LineWidth', 2);
plot(X(M2, :),  Y(M2,  :), 'b', 'LineWidth', 2);
plot(X(:,  N2), Y(:,  N2), 'm', 'LineWidth', 2);
Y = -Y;

axis([-0.5 0.5 -0.5 0.5]);

grid on;
view([0 90]);

xlabel('Re z');
ylabel('Im z');
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
subplot(1, 2, 2);
hold on;

t = title('Verformtes Gitter im Bildbereich: $w = \frac{\ln z}{(1 + z)^{3}}$', 'interpreter', 'latex');
set(t, 'FontSize', 16);

Z = X + i*Y;

W = log(Z)./((1 + Z).^3);
U = real(W);
V = imag(W);
Z = zeros(M, N);
surf(U, V, Z);

plot(U(1,   :), V(1,   :), 'r', 'LineWidth', 2);
plot(U(end, :), V(end, :), 'r', 'LineWidth', 2);
plot(U(:,   1), V(:,   1), 'r', 'LineWidth', 2);
plot(U(:, end), V(:, end), 'r', 'LineWidth', 2);

plot(U(M2, :),  V(M2,  :), 'b', 'LineWidth', 2);
plot(U(:,  N2), V(:,  N2), 'm', 'LineWidth', 2);

Y = -Y;
Z = X + i*Y;

W = log(Z)./((1 + Z).^3);
U = real(W);
V = imag(W);
Z = zeros(M, N);
surf(U, V, Z);

plot(U(1,   :), V(1,   :), 'r', 'LineWidth', 2);
plot(U(end, :), V(end, :), 'r', 'LineWidth', 2);
plot(U(:,   1), V(:,   1), 'r', 'LineWidth', 2);
plot(U(:, end), V(:, end), 'r', 'LineWidth', 2);

plot(U(M2, :),  V(M2,  :), 'b', 'LineWidth', 2);
plot(U(:,  N2), V(:,  N2), 'm', 'LineWidth', 2);

colormap pink;

axis([-7.5 11 -26 26]);

grid on;
view([0 90]);

xlabel('Re w');
ylabel('Im w');
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%